@@ -2,7 +2,7 @@
 Gtk = imports.gi.Gtk;
 GObject = imports.gi.GObject;
 
-Gtk.init(null, null);
+Gtk.init(Seed.argv);
 
 
 var w = new Gtk.Window();
