@@ -1,12 +1,14 @@
 #!/usr/bin/env seed
 
-Seed.import_namespace("Soup");
+Soup = imports.gi.Soup;
 
 var session = new Soup.SessionSync();
 
-var uri = Soup.URI._new("http://www.google.com");
+// Soup.URI is a struct.
+var uri = new Soup.URI.c_new("http://www.google.com");
 var request = new Soup.Message({method:"GET", uri:uri});
 
 var status = session.send_message(request);
-Seed.print(status);
+
+print(status);
 
