@@ -1,22 +1,22 @@
+/* -*- mode: C; indent-tabs-mode: t; tab-width: 8; c-basic-offset: 2; -*- */
+
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
  *
- * Seed is free software: you can redistribute it and/or modify 
+ * Seed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version. 
- * Seed is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
- * GNU Lesser General Public License for more details. 
- * You should have received a copy of the GNU Lesser General Public License 
- * along with Seed.  If not, see <http://www.gnu.org/licenses/>. 
+ * the License, or (at your option) any later version.
+ * Seed is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
+ * Copyright (C) Robert Carr 2009 <carrr@rpi.edu>
  */
 
-#include <string.h>
-
 #include "seed-private.h"
 
 typedef struct _signal_privates
@@ -42,8 +42,7 @@ seed_gobject_signal_connect (JSContextRef ctx,
 			     const gchar * signal_name,
 			     GObject * on_obj,
 			     JSObjectRef func,
-			     JSObjectRef this_obj, 
-			     JSObjectRef user_data)
+			     JSObjectRef this_obj, JSObjectRef user_data)
 {
   GSignalQuery query;
   GClosure *closure;
@@ -52,15 +51,18 @@ seed_gobject_signal_connect (JSContextRef ctx,
 		  &query);
 #ifdef SEED_ENABLE_DEBUG
   {
-    guint function_arity = 
-      seed_value_to_uint (ctx,
-			  seed_object_get_property(ctx, func, "length"),
-			  NULL);
+    guint function_arity = seed_value_to_uint (ctx,
+					       seed_object_get_property (ctx,
+									 func,
+									 "length"),
+					       NULL);
     if (function_arity != query.n_params)
       {
-	SEED_MARK();
-	SEED_NOTE(SIGNAL, "Connecting signal: %s. Function has arity %d, signal expects %d", query.signal_name, function_arity, query.n_params);
-	SEED_MARK();
+	SEED_MARK ();
+	SEED_NOTE (SIGNAL,
+		   "Connecting signal: %s. Function has arity %d, signal expects %d",
+		   query.signal_name, function_arity, query.n_params);
+	SEED_MARK ();
       }
   }
 #endif
@@ -87,22 +89,20 @@ seed_gobject_signal_connect_by_name (JSContextRef ctx,
 
   if (argumentCount < 2 || argumentCount > 3)
     {
-      seed_make_exception (ctx, exception, "ArgumentError", 
+      seed_make_exception (ctx, exception, "ArgumentError",
 			   "Signal connection expected"
-			   " 2 or 3 arguments. Got " "%zd",
-			   argumentCount);
+			   " 2 or 3 arguments. Got " "%zd", argumentCount);
 
       return JSValueMakeNull (ctx);
     }
 
-  if (JSValueIsNull (ctx, arguments[1]) || 
-      !JSValueIsObject (ctx, arguments[1]) || 
+  if (JSValueIsNull (ctx, arguments[1]) ||
+      !JSValueIsObject (ctx, arguments[1]) ||
       !JSObjectIsFunction (ctx, (JSObjectRef) arguments[1]))
     {
       seed_make_exception (ctx, exception, "ArgumentError",
 			   "Signal connection by name "
-			   "requires a function"
-			   " as second argument");
+			   "requires a function" " as second argument");
       return JSValueMakeNull (ctx);
     }
 
@@ -116,7 +116,8 @@ seed_gobject_signal_connect_by_name (JSContextRef ctx,
   obj_type = G_OBJECT_TYPE (obj);
 
   id = seed_gobject_signal_connect (ctx, signal_name, obj,
-			       (JSObjectRef) arguments[1], NULL, user_data);
+				    (JSObjectRef) arguments[1], NULL,
+				    user_data);
 
   g_free (signal_name);
 
@@ -144,13 +145,13 @@ seed_signal_marshal_func (GClosure * closure,
 			  GValue * return_value,
 			  guint n_param_values,
 			  const GValue * param_values,
-			  gpointer invocation_hint,
-			  gpointer marshall_data)
+			  gpointer invocation_hint, gpointer marshall_data)
 {
   SeedClosure *seed_closure = (SeedClosure *) closure;
   JSValueRef *args, exception = 0;
   JSValueRef ret = 0;
-  gint i;
+  guint i;
+  gchar *mes;
 
   JSContextRef ctx = JSGlobalContextCreateInGroup (context_group,
 						   0);
@@ -176,8 +177,7 @@ seed_signal_marshal_func (GClosure * closure,
     args[i] = JSValueMakeNull (ctx);
 
   ret = JSObjectCallAsFunction (ctx, seed_closure->function,
-				NULL,
-				n_param_values + 1, args, &exception);
+				NULL, n_param_values + 1, args, &exception);
 
   if (exception)
     {
@@ -194,7 +194,7 @@ seed_signal_marshal_func (GClosure * closure,
 
   if (exception)
     {
-      gchar *mes = seed_exception_to_string (ctx, exception);
+      mes = seed_exception_to_string (ctx, exception);
       g_warning ("Exception in signal handler return value. %s \n", mes);
       g_free (mes);
     }
@@ -223,18 +223,17 @@ seed_gobject_signal_emit (JSContextRef ctx,
 
   signal_id = g_signal_lookup (privates->signal_name,
 			       G_OBJECT_TYPE (privates->object));
-  
+
   g_signal_query (signal_id, &query);
 
   if (argumentCount != query.n_params)
     {
-      seed_make_exception (ctx, exception, "ArgumentError", 
+      seed_make_exception (ctx, exception, "ArgumentError",
 			   "Signal: %s for type %s expected %u "
 			   "arguments, got %zd",
 			   query.signal_name,
 			   g_type_name (query.itype),
-			   query.n_params,
-			   argumentCount);
+			   query.n_params, argumentCount);
 
       return JSValueMakeNull (ctx);
     }
@@ -283,8 +282,8 @@ seed_gobject_signal_disconnect (JSContextRef ctx,
     }
   id = seed_value_to_ulong (ctx, arguments[0], exception);
   g_signal_handler_disconnect (JSObjectGetPrivate (thisObject), id);
-  
-  return JSValueMakeUndefined(ctx);
+
+  return JSValueMakeUndefined (ctx);
 }
 
 static JSValueRef
@@ -311,14 +310,13 @@ seed_gobject_signal_connect_on_property (JSContextRef ctx,
     {
       seed_make_exception (ctx, exception, "ArgumentError",
 			   "Signal connection expected"
-			   " 1, or 2 arguments. Got "
-			   "%zd", argumentCount);
+			   " 1, or 2 arguments. Got " "%zd", argumentCount);
 
       return JSValueMakeNull (ctx);
     }
-  
-  if (JSValueIsNull (ctx, arguments[0]) || 
-      !JSValueIsObject (ctx, arguments[0]) || 
+
+  if (JSValueIsNull (ctx, arguments[0]) ||
+      !JSValueIsObject (ctx, arguments[0]) ||
       !JSObjectIsFunction (ctx, (JSObjectRef) arguments[0]))
     {
       seed_make_exception (ctx, exception, "ArgumentError",
@@ -328,11 +326,14 @@ seed_gobject_signal_connect_on_property (JSContextRef ctx,
     }
 
   if (argumentCount == 1)
-    id = seed_gobject_signal_connect (ctx, privates->signal_name,
-				      privates->object,
-				      (JSObjectRef) arguments[0], this_obj, NULL);
+    {
+      id = seed_gobject_signal_connect (ctx, privates->signal_name,
+					privates->object,
+					(JSObjectRef) arguments[0], this_obj,
+					NULL);
 
-  if (argumentCount == 2)
+    }
+  else if (argumentCount == 2)
     {
       id = seed_gobject_signal_connect (ctx, privates->signal_name,
 					privates->object,
@@ -343,15 +344,19 @@ seed_gobject_signal_connect_on_property (JSContextRef ctx,
   return seed_value_from_ulong (ctx, id, exception);
 }
 
-JSStaticFunction signal_static_functions[] = { 
-  {"connect", seed_gobject_signal_connect_on_property, 0},
-  {"emit", seed_gobject_signal_emit, 0},
+JSStaticFunction signal_static_functions[] = {
+  {"connect", seed_gobject_signal_connect_on_property, 0}
+  ,
+  {"emit", seed_gobject_signal_emit, 0}
+  ,
   {0, 0, 0}
 };
 
-JSStaticFunction signal_holder_static_functions [] = {
-  {"connect", seed_gobject_signal_connect_by_name, 0},
-  {"disconnect", seed_gobject_signal_disconnect, 0},
+JSStaticFunction signal_holder_static_functions[] = {
+  {"connect", seed_gobject_signal_connect_by_name, 0}
+  ,
+  {"disconnect", seed_gobject_signal_disconnect, 0}
+  ,
   {0, 0, 0}
 };
 
@@ -379,7 +384,7 @@ static JSValueRef
 seed_signal_holder_get_property (JSContextRef ctx,
 				 JSObjectRef object,
 				 JSStringRef property_name,
-				 JSValueRef *exception)
+				 JSValueRef * exception)
 {
   GObject *gobj = JSObjectGetPrivate (object);
   signal_privates *priv;
@@ -388,26 +393,28 @@ seed_signal_holder_get_property (JSContextRef ctx,
   JSObjectRef signal_ref;
 
   JSStringGetUTF8CString (property_name, signal_name, length);
-  
-  if (!strcmp (signal_name, "connect") || !strcmp (signal_name, "disconnect"))
+
+  if (!
+      (g_strcmp0 (signal_name, "connect")
+       && g_strcmp0 (signal_name, "disconnect")))
     {
       g_free (signal_name);
       return NULL;
     }
-  
+
   if (!g_signal_lookup (signal_name, G_OBJECT_TYPE (gobj)))
     {
       g_free (signal_name);
       return NULL;
     }
-  
+
   priv = g_slice_alloc (sizeof (signal_privates));
 
   priv->object = gobj;
   priv->signal_name = signal_name;
-  
+
   signal_ref = JSObjectMake (ctx, gobject_signal_class, priv);
-  
+
   return signal_ref;
 }
 
