@@ -1,23 +1,23 @@
+/* -*- mode: C; indent-tabs-mode: t; tab-width: 8; c-basic-offset: 2; -*- */
+
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
  *
- * Seed is free software: you can redistribute it and/or modify 
+ * Seed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version. 
- * Seed is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
- * GNU Lesser General Public License for more details. 
- * You should have received a copy of the GNU Lesser General Public License 
- * along with Seed.  If not, see <http://www.gnu.org/licenses/>. 
+ * the License, or (at your option) any later version.
+ * Seed is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
  *
- *Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
+ * Copyright (C) Robert Carr 2009 <carrr@rpi.edu>
  */
 
 #include "seed-private.h"
-#include <stdio.h>
-#include <string.h>
 JSClassRef seed_struct_class = 0;
 JSClassRef seed_union_class = 0;
 JSClassRef seed_pointer_class = 0;
@@ -84,7 +84,7 @@ seed_boxed_finalize (JSObjectRef object)
 GIFieldInfo *
 seed_union_find_field (GIUnionInfo * info, gchar * field_name)
 {
-  int n, i;
+  gint n, i;
   GIFieldInfo *field;
 
   n = g_union_info_get_n_fields (info);
@@ -94,35 +94,35 @@ seed_union_find_field (GIUnionInfo * info, gchar * field_name)
 
       field = g_union_info_get_field (info, i);
       name = g_base_info_get_name ((GIBaseInfo *) field);
-      if (!strcmp (name, field_name))
+      if (!g_strcmp0 (name, field_name))
 	return field;
       else
 	g_base_info_unref ((GIBaseInfo *) field);
     }
 
-  return 0;
+  return NULL;
 }
 
 GIFieldInfo *
 seed_struct_find_field (GIStructInfo * info, gchar * field_name)
 {
-  int n, i;
+  gint n, i;
+  const gchar *name;
   GIFieldInfo *field;
 
   n = g_struct_info_get_n_fields (info);
   for (i = 0; i < n; i++)
     {
-      const gchar *name;
 
       field = g_struct_info_get_field (info, i);
       name = g_base_info_get_name ((GIBaseInfo *) field);
-      if (!strcmp (name, field_name))
+      if (!g_strcmp0 (name, field_name))
 	return field;
       else
 	g_base_info_unref ((GIBaseInfo *) field);
     }
 
-  return 0;
+  return NULL;
 }
 
 JSValueRef
@@ -131,8 +131,10 @@ seed_field_get_value (JSContextRef ctx,
 		      GIFieldInfo * field, JSValueRef * exception)
 {
   GITypeInfo *field_type;
+  GIBaseInfo *interface;
   GArgument field_value;
-  JSValueRef ret = JSValueMakeNull (ctx);;
+  JSValueRef ret = JSValueMakeNull (ctx);
+  gint offset;
 
   field_type = g_field_info_get_type (field);
   if (!g_field_info_get_field (field, object, &field_value))
@@ -142,10 +144,8 @@ seed_field_get_value (JSContextRef ctx,
       tag = g_type_info_get_tag (field_type);
       if (tag == GI_TYPE_TAG_INTERFACE)
 	{
-	  GIBaseInfo *interface;
-
 	  interface = g_type_info_get_interface (field_type);
-	  gint offset = g_field_info_get_offset (field);
+	  offset = g_field_info_get_offset (field);
 
 	  g_base_info_unref ((GIBaseInfo *) field_type);
 	  switch (g_base_info_get_type (interface))
@@ -183,7 +183,7 @@ seed_union_get_property (JSContextRef context,
 			 JSStringRef property_name, JSValueRef * exception)
 {
   gchar *cproperty_name;
-  int length;
+  gsize length;
   seed_struct_privates *priv = JSObjectGetPrivate (object);
   GIFieldInfo *field = 0;
   JSValueRef ret;
@@ -215,7 +215,7 @@ seed_union_set_property (JSContextRef context,
 			 JSStringRef property_name,
 			 JSValueRef value, JSValueRef * exception)
 {
-  gint length;
+  gsize length;
   GArgument field_value;
   GIFieldInfo *field;
   gchar *cproperty_name;
@@ -236,12 +236,13 @@ seed_union_set_property (JSContextRef context,
 
   if (!field)
     {
-      return 0;
+      return FALSE;
     }
 
   field_type = g_field_info_get_type (field);
 
-  seed_gi_make_argument (context, value, field_type, NULL, &field_value, exception);
+  seed_gi_make_argument (context, value, field_type, NULL, &field_value,
+			 exception);
   ret = g_field_info_set_field (field, priv->pointer, &field_value);
 
   g_base_info_unref ((GIBaseInfo *) field_type);
@@ -256,7 +257,7 @@ seed_struct_set_property (JSContextRef context,
 			  JSStringRef property_name,
 			  JSValueRef value, JSValueRef * exception)
 {
-  gint length;
+  gsize length;
   GArgument field_value;
   GIFieldInfo *field;
   gchar *cproperty_name;
@@ -278,12 +279,13 @@ seed_struct_set_property (JSContextRef context,
 
   if (!field)
     {
-      return 0;
+      return FALSE;
     }
 
   field_type = g_field_info_get_type (field);
 
-  seed_gi_make_argument (context, value, field_type, NULL, &field_value, exception);
+  seed_gi_make_argument (context, value, field_type, NULL, &field_value,
+			 exception);
   ret = g_field_info_set_field (field, priv->pointer, &field_value);
 
   g_base_info_unref ((GIBaseInfo *) field_type);
@@ -298,9 +300,9 @@ seed_struct_get_property (JSContextRef context,
 			  JSStringRef property_name, JSValueRef * exception)
 {
   gchar *cproperty_name;
-  int length;
+  gsize length;
   seed_struct_privates *priv = JSObjectGetPrivate (object);
-  GIFieldInfo *field = 0;
+  GIFieldInfo *field = NULL;
   JSValueRef ret;
 
   length = JSStringGetMaximumUTF8CStringSize (property_name);
@@ -316,7 +318,7 @@ seed_struct_get_property (JSContextRef context,
 
   if (!field)
     {
-      return 0;
+      return NULL;
     }
 
   ret = seed_field_get_value (context, priv->pointer, field, exception);
@@ -460,7 +462,7 @@ seed_pointer_get_pointer (JSContextRef ctx, JSValueRef pointer)
       seed_struct_privates *priv = JSObjectGetPrivate ((JSObjectRef) pointer);
       return priv->pointer;
     }
-  return 0;
+  return NULL;
 }
 
 void
@@ -501,6 +503,7 @@ seed_union_prototype (JSContextRef ctx, GIBaseInfo * info)
   const gchar *namespace, *name;
   gchar *key;
   gint n_methods, i;
+  GIFunctionInfo *finfo;
 
   name = g_base_info_get_name (info);
   namespace = g_base_info_get_namespace (info);
@@ -516,8 +519,6 @@ seed_union_prototype (JSContextRef ctx, GIBaseInfo * info)
       n_methods = g_union_info_get_n_methods ((GIUnionInfo *) info);
       for (i = 0; i < n_methods; i++)
 	{
-	  GIFunctionInfo *finfo;
-
 	  finfo = g_union_info_get_method ((GIUnionInfo *) info, i);
 
 	  seed_gobject_define_property_from_function_info (ctx,
@@ -627,8 +628,7 @@ seed_struct_prototype (JSContextRef ctx, GIBaseInfo * info)
 JSObjectRef
 seed_make_struct (JSContextRef ctx, gpointer strukt, GIBaseInfo * info)
 {
-  JSObjectRef object;
-  JSObjectRef proto;
+  JSObjectRef object, proto;
   seed_struct_privates *priv = g_slice_alloc (sizeof (seed_struct_privates));
 
   priv->info = info ? g_base_info_ref (info) : 0;
@@ -674,13 +674,15 @@ seed_construct_struct_type_with_parameters (JSContextRef ctx,
   gpointer object;
   GIInfoType type = g_base_info_get_type (info);
   JSObjectRef ret;
-  gint nparams, i = 0, length;
+  gint nparams, i = 0;
+  gsize length;
   GIFieldInfo *field = 0;
   JSPropertyNameArrayRef jsprops;
   JSStringRef jsprop_name;
   JSValueRef jsprop_value;
   GArgument field_value;
   gchar *prop_name;
+  GITypeInfo *field_type;
 
   if (type == GI_INFO_TYPE_STRUCT)
     {
@@ -713,7 +715,6 @@ seed_construct_struct_type_with_parameters (JSContextRef ctx,
 
   while (i < nparams)
     {
-      GITypeInfo *field_type;
       jsprop_name = JSPropertyNameArrayGetNameAtIndex (jsprops, i);
 
       length = JSStringGetMaximumUTF8CStringSize (jsprop_name);
@@ -726,7 +727,7 @@ seed_construct_struct_type_with_parameters (JSContextRef ctx,
 	field = seed_union_find_field ((GIUnionInfo *) info, prop_name);
       if (!field)
 	{
-	  seed_make_exception (ctx, exception, "PropertyError", 
+	  seed_make_exception (ctx, exception, "PropertyError",
 			       "Invalid property for construction: %s",
 			       prop_name);
 
