@@ -4,4 +4,4 @@
 // STDOUT:Hello World!\n\[undefined\]
 // STDERR:
 
-Seed.print(Seed.print("Hello World!"));
+print(print("Hello World!"));
